@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2015 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,6 +50,7 @@
 package com.openexchange.saml.impl;
 
 import static com.openexchange.saml.SAMLProperties.ACS_URL;
+import static com.openexchange.saml.SAMLProperties.ENABLE_AUTO_LOGIN;
 import static com.openexchange.saml.SAMLProperties.ENABLE_METADATA_SERVICE;
 import static com.openexchange.saml.SAMLProperties.ENABLE_SINGLE_LOGOUT;
 import static com.openexchange.saml.SAMLProperties.ENTITY_ID;
@@ -96,6 +97,8 @@ public class DefaultConfig implements SAMLConfig {
 
     private String logoutResponseTemplate;
 
+    private boolean autoLoginEnabled;
+
 
     private DefaultConfig() {
         super();
@@ -121,6 +124,7 @@ public class DefaultConfig implements SAMLConfig {
         }
 
         config.setEnableMetadataService(configService.getBoolProperty(ENABLE_METADATA_SERVICE, false));
+        config.setAutoLoginEnabled(configService.getBoolProperty(ENABLE_AUTO_LOGIN, false));
         return config;
     }
 
@@ -199,6 +203,11 @@ public class DefaultConfig implements SAMLConfig {
         return logoutResponseTemplate;
     }
 
+    @Override
+    public boolean isAutoLoginEnabled() {
+        return autoLoginEnabled;
+    }
+
     private void setProviderName(String providerName) {
         this.providerName = providerName;
     }
@@ -243,4 +252,8 @@ public class DefaultConfig implements SAMLConfig {
         this.logoutResponseTemplate = logoutResponseTemplate;
     }
 
+    private void setAutoLoginEnabled(boolean autoLoginEnabled) {
+        this.autoLoginEnabled = autoLoginEnabled;;
+    }
+
 }
